# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:59:40 2018 from module list in Acme::CPANLists::Import::BKB::FastCGI version 0.001.

package Acme::CPANModules::Import::BKB::FastCGI;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [https://www.lemoda.net/perl/fastcgi-modules/index.html] (retrieved on 2017-03-27). Visit the URL for the full contents.",
  entries     => [
                   { module => "AnyEvent::FCGI" },
                   { module => "CGI::Application::FastCGI" },
                   { module => "CGI::Fast" },
                   { module => "FCGI" },
                   { module => "FCGI::Async" },
                   { module => "FCGI::Client" },
                   { module => "FCGI::EV" },
                   { module => "Mojo::Server::FastCGI" },
                   { module => "Net::FastCGI" },
                   { module => "POE::Component::FastCGI" },
                   { module => "Plack::Handler::FCGI" },
                 ],
  summary     => "FastCGI Perl modules (2016)",
};

1;
# ABSTRACT: FastCGI Perl modules (2016)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::BKB::FastCGI - FastCGI Perl modules (2016)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::BKB::FastCGI (from Perl distribution Acme-CPANModulesBundle-Import-BKB), released on 2018-09-22.

=head1 DESCRIPTION

FastCGI Perl modules (2016).

This list is generated by extracting module names mentioned in [https://www.lemoda.net/perl/fastcgi-modules/index.html] (retrieved on 2017-03-27). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<AnyEvent::FCGI>

=item * L<CGI::Application::FastCGI>

=item * L<CGI::Fast>

=item * L<FCGI>

=item * L<FCGI::Async>

=item * L<FCGI::Client>

=item * L<FCGI::EV>

=item * L<Mojo::Server::FastCGI>

=item * L<Net::FastCGI>

=item * L<POE::Component::FastCGI>

=item * L<Plack::Handler::FCGI>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-BKB>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-BKB>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-BKB>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
