# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:59:40 2018 from module list in Acme::CPANLists::Import::BKB::Handy version 0.001.

package Acme::CPANModules::Import::BKB::Handy;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [https://www.lemoda.net/perl/handy-modules/index.html] (retrieved on 2017-03-27). Visit the URL for the full contents.",
  entries     => [
                   { module => "App::cpanminus" },
                   { module => "CGI" },
                   { module => "Carp" },
                   { module => "DBD::SQLite" },
                   { module => "DBD::mysql" },
                   { module => "DBI" },
                   { module => "ExtUtils::MakeMaker" },
                   { module => "File::Copy" },
                   { module => "File::Find" },
                   { module => "File::Spec" },
                   { module => "File::Temp" },
                   { module => "FindBin" },
                   { module => "Module::Build" },
                   { module => "Template" },
                   { module => "Test" },
                   { module => "Test::More" },
                   { module => "Test::Simple" },
                 ],
  summary     => "Handy Perl modules (2011)",
};

1;
# ABSTRACT: Handy Perl modules (2011)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::BKB::Handy - Handy Perl modules (2011)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::BKB::Handy (from Perl distribution Acme-CPANModulesBundle-Import-BKB), released on 2018-09-22.

=head1 DESCRIPTION

Handy Perl modules (2011).

This list is generated by extracting module names mentioned in [https://www.lemoda.net/perl/handy-modules/index.html] (retrieved on 2017-03-27). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<App::cpanminus>

=item * L<CGI>

=item * L<Carp>

=item * L<DBD::SQLite>

=item * L<DBD::mysql>

=item * L<DBI>

=item * L<ExtUtils::MakeMaker>

=item * L<File::Copy>

=item * L<File::Find>

=item * L<File::Spec>

=item * L<File::Temp>

=item * L<FindBin>

=item * L<Module::Build>

=item * L<Template>

=item * L<Test>

=item * L<Test::More>

=item * L<Test::Simple>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-BKB>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-BKB>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-BKB>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
